



text = f"""
#-- Welcome to NICS settings!
#----------------------------

#-- Everything starts with "#--" is a comment.
#-- Help: https://nvfp.github.io/now-i-can-sleep


author: 'Nicholas Valentinus'
color_hue: 28
show_credit: True


#-- The variables below should not be changed and are for NICS internal use only.

_gh_username: 'nvfp'
_gh_repo: 'now-i-can-sleep'
"""